@@ -1,19 +1,19 @@
 #![allow(unused_imports)]
-use super::super::diagram::VoronoiDiagram;
+use super::super::diagram::Diagram;
 use super::super::BvError;
 use super::Builder;
 use super::{Line, Point};
 
 #[test]
 fn sort_1() {
-    type I1 = i32;
-    type F1 = f32;
+    type I = i32;
+    type F = f32;
     {
         let coord = |x, y| Point { x, y };
 
         let _v = vec![coord(10, 11), coord(0, 100), coord(10, 11), coord(0, 100)];
 
-        let mut vb = Builder::<I1, F1>::default();
+        let mut vb = Builder::<I, F>::default();
         assert!(vb.site_events_.is_empty());
         vb.with_vertices(_v.iter()).expect("sort_1");
         assert_eq!(vb.site_events_.len(), 4);
