@@ -12,16 +12,14 @@
 use super::beach_line as VB;
 use super::extended_exp_fpt as EX;
 
-use super::OutputType;
 #[cfg(feature = "console_debug")]
 use crate::tln;
-use crate::BvError;
+use crate::{BvError, GrowingVob, VobU32};
 use ordered_float::OrderedFloat;
 use std::cell::Cell;
 use std::cmp::Ordering;
 use std::collections::BTreeSet;
 use std::fmt;
-use std::ops::Neg;
 use std::rc::Rc;
 
 /// Type-checked placeholder for usize
@@ -240,10 +238,7 @@ impl PartialEq for CircleEventC {
 
 impl Eq for CircleEventC {}
 
-impl CircleEvent
-where
-    f64: OutputType + Neg<Output = f64>,
-{
+impl CircleEvent {
     pub(crate) fn new_1(bech_line_index: VB::BeachLineIndex) -> CircleEvent {
         Self {
             center_x_: OrderedFloat(0_f64),
@@ -376,7 +371,7 @@ pub(crate) struct CircleEventQueue {
     // circle events sorted by id
     c_list_: ahash::AHashMap<usize, CircleEventType>,
     c_list_next_free_index_: CircleEventIndex,
-    inactive_circle_ids_: yabf::Yabf, // Circle events turned inactive
+    inactive_circle_ids_: VobU32, // Circle events turned inactive
 }
 
 impl Default for CircleEventQueue {
@@ -385,7 +380,7 @@ impl Default for CircleEventQueue {
             c_: BTreeSet::new(),
             c_list_: ahash::AHashMap::new(),
             c_list_next_free_index_: CircleEventIndex(0),
-            inactive_circle_ids_: yabf::Yabf::default(),
+            inactive_circle_ids_: VobU32::fill(128),
         }
     }
 }
@@ -486,7 +481,7 @@ impl CircleEventQueue {
         if let Some(circle) = self.pop_first() {
             if let Some(circle_id) = circle.0.get().index_ {
                 let _ = self.c_list_.remove(&circle_id.0);
-                let _ = self.inactive_circle_ids_.set_bit(circle_id.0, true);
+                self.inactive_circle_ids_.set_grow(circle_id.0, true);
             } else {
                 return Err(BvError::InternalError(format!(
                     "circle event lists corruption, circle event id {:?} not found {}:{}",
@@ -511,7 +506,11 @@ impl CircleEventQueue {
     pub(crate) fn clear(&mut self) {
         self.c_.clear();
         self.c_list_.clear();
-        self.inactive_circle_ids_ = yabf::Yabf::default()
+        self.inactive_circle_ids_ = {
+            let mut cids = VobU32::fill(512);
+            cids.resize(512, false);
+            cids
+        }
     }
 
     /// Take ownership of the circle event,
@@ -536,23 +535,23 @@ impl CircleEventQueue {
 
     #[inline(always)]
     pub(crate) fn is_active(&self, circle_event_id: CircleEventIndex) -> bool {
-        !self.inactive_circle_ids_.bit(circle_event_id.0)
+        !self.inactive_circle_ids_.get_f(circle_event_id.0)
     }
 
     pub(crate) fn deactivate(&mut self, circle_event_id: Option<CircleEventIndex>) {
         #[cfg(not(feature = "console_debug"))]
         if let Some(circle_event_id) = circle_event_id {
-            let _ = self.inactive_circle_ids_.set_bit(circle_event_id.0, true);
+            self.inactive_circle_ids_.set_grow(circle_event_id.0, true);
         }
         #[cfg(feature = "console_debug")]
         if let Some(circle_event_id) = circle_event_id {
-            if !self.inactive_circle_ids_.bit(circle_event_id.0) {
+            if !self.inactive_circle_ids_.get_f(circle_event_id.0) {
                 if self.c_list_.contains_key(&circle_event_id.0) {
                     tln!("deactivate {:?}", self.c_list_[&circle_event_id.0]);
                 } else {
                     tln!("circle {} not present", circle_event_id);
                 }
-                let _ = self.inactive_circle_ids_.set_bit(circle_event_id.0, true);
+                self.inactive_circle_ids_.set_grow(circle_event_id.0, true);
             }
         }
     }
