@@ -9,27 +9,32 @@
 
 // Ported from C++ boost 1.76.0 to Rust in 2020/2021 by Eadf (github.com/eadf)
 
-#![deny(non_camel_case_types)]
-#![deny(unused_parens)]
-#![deny(non_upper_case_globals)]
-#![deny(unused_qualifications)]
-#![deny(unused_results)]
-#![deny(unused_imports)]
-#![deny(bare_trait_objects)]
-#![deny(ellipsis_inclusive_range_patterns)]
-#![deny(elided_lifetimes_in_paths)]
+#![deny(
+    rust_2018_compatibility,
+    rust_2018_idioms,
+    nonstandard_style,
+    unused,
+    future_incompatible,
+    non_camel_case_types,
+    unused_parens,
+    non_upper_case_globals,
+    unused_qualifications,
+    unused_results,
+    unused_imports,
+    unused_variables,
+    bare_trait_objects,
+    ellipsis_inclusive_range_patterns,
+    elided_lifetimes_in_paths
+)]
 #![cfg_attr(feature = "map_first_last", feature(map_first_last))]
 
-#[cfg(test)]
-extern crate lazy_static;
 use core::fmt::Debug;
 use extended_exp_fpt as EX;
 use extended_int as EI;
-use num::{Float, NumCast, PrimInt, Zero};
+use num::{Float, Integer, NumCast, PrimInt, Signed, Zero};
 use std::fmt;
 use std::hash::Hash;
 use std::marker::PhantomData;
-use std::ops::Neg;
 
 mod beach_line;
 pub mod builder;
@@ -42,9 +47,8 @@ pub mod extended_exp_fpt;
 // I'd prefer if this module could be pub (crate), but then the documentation examples would not work.
 pub mod extended_int;
 pub mod file_reader;
-pub(crate) mod predicate;
-// I'd prefer if this module could be pub (crate), but then the documentation examples would not work.
 pub mod geometry;
+pub(crate) mod predicate;
 pub mod robust_fpt;
 mod site_event;
 pub mod sync_diagram;
@@ -104,82 +108,29 @@ pub enum BvError {
     BvError(#[from] std::io::Error),
 }
 
-/// This is the integer input type of the algorithm. Typically i32 or i64.
+/// This is the integer input type of the algorithm. i32 or i64.
 pub trait InputType:
-    fmt::Display
-    + Ord
-    + PartialOrd
-    + Eq
-    + PartialEq
-    + Hash
-    + PrimInt
-    + Copy
-    + Clone
-    + NumCast
-    + Debug
-    + Zero
-    + Default
-    + Unpin
+    fmt::Display + Hash + Integer + PrimInt + Debug + Default + Unpin + Signed
 {
 }
 
-impl<I> InputType for I where
-    I: fmt::Display
-        + Ord
-        + PartialOrd
-        + Eq
-        + PartialEq
-        + Hash
-        + PrimInt
-        + Copy
-        + Clone
-        + NumCast
-        + Debug
-        + Zero
-        + Default
-        + Unpin
-{
-}
+impl InputType for i64 {}
+impl InputType for i32 {}
 
-/// This is the floating point output type of the algorithm. Typically f32 or f64.
+/// This is the floating point output type of the algorithm. f32 or f64.
 pub trait OutputType:
-    Float
-    + PartialOrd
-    + PartialEq
-    + NumCast
-    + Copy
-    + Clone
-    + fmt::Display
-    + Default
-    + Debug
-    + Zero
-    + std::ops::MulAssign
-    + Unpin
+    Float + Debug + Zero + Unpin + fmt::Display + std::ops::MulAssign + Default
 {
 }
 
-impl<F> OutputType for F where
-    F: Float
-        + PartialOrd
-        + PartialEq
-        + NumCast
-        + Copy
-        + Clone
-        + fmt::Display
-        + Default
-        + Debug
-        + Zero
-        + std::ops::MulAssign
-        + Unpin
-        + Neg<Output = F>
-{
-}
+impl OutputType for f32 {}
+impl OutputType for f64 {}
 
 /// Functions for converting the integer input type to other types (i32 i64 etc.)
 #[derive(Default)]
 pub struct TypeConverter1<I>
 where
-    I: InputType + Neg<Output = I>,
+    I: InputType,
 {
     #[doc(hidden)]
     pdi_: PhantomData<I>,
@@ -187,7 +138,7 @@ where
 
 impl<I> TypeConverter1<I>
 where
-    I: InputType + Neg<Output = I>,
+    I: InputType,
 {
     #[inline(always)]
     /// Convert from the input integer type to an extended int
@@ -230,8 +181,8 @@ where
 #[derive(Default)]
 pub struct TypeConverter2<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -241,8 +192,8 @@ where
 
 impl<I, F> TypeConverter2<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[inline(always)]
     /// Convert from the input integer type to the output float type
@@ -305,3 +256,36 @@ where
         EX::ExtendedExponentFpt::from(input)
     }
 }
+
+pub(crate) type VobU32 = vob::Vob<u32>;
+
+pub(crate) trait GrowingVob {
+    /// Will create a new Vob and fill it with `false`
+    fn fill(initial_size: usize) -> Self;
+    /// Conditionally grow to fit required size, set ´bit´ to ´state´ value
+    fn set_grow(&mut self, bit: usize, state: bool);
+    /// get() with default value `false`
+    fn get_f(&self, bit: usize) -> bool;
+}
+
+impl<T:PrimInt+Debug> GrowingVob for vob::Vob<T> {
+    #[inline]
+    fn fill(initial_size: usize) -> Self {
+        let mut v = Self::new_with_storage_type(0);
+        v.resize(initial_size, false);
+        v
+    }
+
+    #[inline]
+    fn set_grow(&mut self, bit: usize, state: bool) {
+        if bit >= self.len() {
+            self.resize(bit + std::mem::size_of::<T>(), false);
+        }
+        let _ = self.set(bit, state);
+    }
+
+    #[inline]
+    fn get_f(&self, bit: usize) -> bool {
+        self.get(bit).unwrap_or(false)
+    }
+}
