@@ -25,7 +25,6 @@ use super::site_event as VSE;
 use super::TypeConverter1 as TC1;
 use super::TypeConverter2 as TC2;
 use super::{InputType, OutputType};
-#[allow(unused_imports)]
 use crate::{t, tln};
 use num::{Float, NumCast, PrimInt, Zero};
 use std::cmp;
@@ -64,8 +63,8 @@ impl Debug for SiteIndex {
 #[derive(Default)]
 pub struct Predicates<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -75,8 +74,8 @@ where
 
 impl<I, F> Predicates<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[inline(always)]
     pub(crate) fn is_vertical_1(site: &VSE::SiteEvent<I, F>) -> bool {
@@ -178,8 +177,8 @@ enum Orientation {
 #[derive(Default)]
 pub struct OrientationTest<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -189,8 +188,8 @@ where
 
 impl<I, F> OrientationTest<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     /// Value is a determinant of two vectors (e.g. x1 * y2 - x2 * y1).
     /// Return orientation based on the sign of the determinant.
@@ -207,25 +206,26 @@ where
 
     #[inline(always)]
     fn eval_p(point1: &Point<I>, point2: &Point<I>, point3: &Point<I>) -> Orientation {
-        let i_to_i64 = TC1::<I>::i_to_i64;
-        let dx1: i64 = i_to_i64(point1.x) - i_to_i64(point2.x);
-        let dx2: i64 = i_to_i64(point2.x) - i_to_i64(point3.x);
-        let dy1: i64 = i_to_i64(point1.y) - i_to_i64(point2.y);
-        let dy2: i64 = i_to_i64(point2.y) - i_to_i64(point3.y);
+        let dx1: i64 = TC1::<I>::i_to_i64(point1.x) - TC1::<I>::i_to_i64(point2.x);
+        let dx2: i64 = TC1::<I>::i_to_i64(point2.x) - TC1::<I>::i_to_i64(point3.x);
+        let dy1: i64 = TC1::<I>::i_to_i64(point1.y) - TC1::<I>::i_to_i64(point2.y);
+        let dy2: i64 = TC1::<I>::i_to_i64(point2.y) - TC1::<I>::i_to_i64(point3.y);
         let cp: f64 = Predicates::<I, F>::robust_cross_product(dx1, dy1, dx2, dy2);
         Self::eval_f(cp)
     }
 
     #[inline(always)]
     fn eval_i(dif_x1: i64, dif_y1: i64, dif_x2: i64, dif_y2: i64) -> Orientation {
-        Self::eval_f( Predicates::<I, F>::robust_cross_product(dif_x1, dif_y1, dif_x2, dif_y2))
+        Self::eval_f(Predicates::<I, F>::robust_cross_product(
+            dif_x1, dif_y1, dif_x2, dif_y2,
+        ))
     }
 }
 
 #[derive(Default)]
 pub struct PointComparisonPredicate<I>
 where
-    I: InputType + Neg<Output = I>,
+    I: InputType,
 {
     #[doc(hidden)]
     pdi_: PhantomData<I>,
@@ -233,7 +233,7 @@ where
 
 impl<I> PointComparisonPredicate<I>
 where
-    I: InputType + Neg<Output = I>,
+    I: InputType,
 {
     /// returns true if lhs.x < rhs.x, if lhs.x==rhs.x it returns lhs.y < rhs.y
     #[inline(always)]
@@ -249,8 +249,8 @@ where
 #[derive(Default)]
 pub struct EventComparisonPredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -260,8 +260,8 @@ where
 
 impl<I, F> EventComparisonPredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     /// boolean predicate between two sites (bool int int)
     pub(crate) fn event_comparison_predicate_bii(
@@ -363,8 +363,8 @@ enum KPredicateResult {
 
 pub struct DistancePredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdo_: PhantomData<F>,
@@ -374,8 +374,8 @@ where
 
 impl<I, F> DistancePredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[cfg(feature = "console_debug")]
     #[allow(dead_code)]
@@ -612,8 +612,8 @@ where
 
 pub struct NodeComparisonPredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -623,8 +623,8 @@ where
 
 impl<I, F> NodeComparisonPredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     /// Compares nodes in the balanced binary search tree. Nodes are
     /// compared based on the y coordinates of the arcs intersection points.
@@ -749,8 +749,8 @@ where
 
 pub struct CircleExistencePredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -760,8 +760,8 @@ where
 
 impl<I, F> CircleExistencePredicate<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[inline(always)]
     pub(crate) fn ppp(
@@ -788,6 +788,7 @@ where
             c_event.0.get().y().0,
             c_event.0.get().lower_x().0
         );
+        #[allow(clippy::match_like_matches_macro)]
         if match (_site1.is_point(), _site2.is_point(), _site3.is_point()) {
             // only validate pps
             (false, true, true) => true,
@@ -883,8 +884,8 @@ where
 #[derive(Default)]
 pub struct LazyCircleFormationFunctor<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -895,16 +896,11 @@ where
 #[allow(non_snake_case)]
 impl<I, F> LazyCircleFormationFunctor<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     /// Lazy evaluation of point, point, point circle events
-    fn ppp(
-        point1: &Point<I>,
-        point2: &Point<I>,
-        point3: &Point<I>,
-        c_event: &VC::CircleEventType,
-    ) {
+    fn ppp(point1: &Point<I>, point2: &Point<I>, point3: &Point<I>, c_event: &VC::CircleEventType) {
         let i_to_f64 = TC1::<I>::i_to_f64;
         let i_to_i64 = TC1::<I>::i_to_i64;
 
@@ -1502,7 +1498,7 @@ where
                     Predicates::<I, F>::robust_cross_product(
                         i_to_i64(segm_end2.x) - i_to_i64(segm_start2.x),
                         i_to_i64(segm_end2.y) - i_to_i64(segm_start2.y),
-                        i_to_i64(-site1.y()),
+                        -i_to_i64(site1.y()),
                         i_to_i64(site1.x()),
                     ),
                     1_f64,
@@ -1513,7 +1509,7 @@ where
                     Predicates::<I, F>::robust_cross_product(
                         i_to_i64(segm_end1.x) - i_to_i64(segm_start1.x),
                         i_to_i64(segm_end1.y) - i_to_i64(segm_start1.y),
-                        i_to_i64(-site1.y()),
+                        -i_to_i64(site1.y()),
                         i_to_i64(site1.x()),
                     ),
                     1_f64,
@@ -1759,8 +1755,8 @@ where
 #[derive(Default)]
 pub struct CircleFormationFunctor<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -1770,8 +1766,8 @@ where
 
 impl<I, F> CircleFormationFunctor<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     pub(crate) fn lies_outside_vertical_segment(
         c: &VC::CircleEventType,
@@ -1813,8 +1809,7 @@ where
             site3.is_segment()
         );
 
-        let rv = Self::circle_formation_predicate(site1, site2, site3, circle);
-        rv
+        Self::circle_formation_predicate(site1, site2, site3, circle)
     }
 
     /// Create a circle event from the given three sites.
@@ -1833,7 +1828,12 @@ where
                     if !CircleExistencePredicate::<I, F>::ppp(site1, site2, site3) {
                         return false;
                     }
-                    LazyCircleFormationFunctor::<I, F>::ppp(site1.point0(), site2.point0(), site3.point0(), circle);
+                    LazyCircleFormationFunctor::<I, F>::ppp(
+                        site1.point0(),
+                        site2.point0(),
+                        site3.point0(),
+                        circle,
+                    );
                 } else {
                     // (point, point, segment) sites.
                     if !CircleExistencePredicate::<I, F>::pps(site1, site2, site3, SiteIndex::Three)
@@ -1930,8 +1930,8 @@ where
 #[derive(Default)]
 pub struct ExactCircleFormationFunctor<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     #[doc(hidden)]
     pdf_: PhantomData<F>,
@@ -1941,8 +1941,8 @@ where
 
 impl<I, F> ExactCircleFormationFunctor<I, F>
 where
-    I: InputType + Neg<Output = I>,
-    F: OutputType + Neg<Output = F>,
+    I: InputType,
+    F: OutputType,
 {
     /// Recompute parameters of the point, point, point circle event using high-precision library.
     fn ppp(
